// Copyright [2013] Alexander Rush

#include "Hypergraph/Factory.hh"
